#!/bin/bash
################################################################
#
# install.sh
#
# Installation program for createusers.
#
################################################################

version=1.3.3

#############
# Main code #
#############

# See if we are root.
if ! [ $UID -eq 0 ] 
then 
     echo "You must be root to run this program."
     exit 1
fi

# Ask where to put the manual pages.
# echo "What is the directory for commands (section 1) manual pages? "
# echo -n "(eg: /usr/share/man/man1 or /usr/man/man1) "
# read man_dir
man_dir="/usr/share/man/man1"
#
# See if the directory exists.
if ! test -d $man_dir; then
     echo "The directory $man_dir does not exist." >&2
     exit 1
fi

# Copy the man pages to the man directory.
echo "Copying man pages to $man_dir"
cp man/*.gz $man_dir

# Copy the docs to the docs directory.
mkdir -p /usr/share/doc/createusers-$version
echo "Copying docs to /usr/share/doc/createusers-$version"
cp CHANGES COPYING INSTALL README SECURITY users.sample names.sample \
   /usr/share/doc/createusers-$version

# Copy the configuration file unless the destination is newer
echo "Copying configuration file to /etc/createusers.conf unless dest is newer"
cp -u createusers.conf /etc/createusers.conf 
chown root.root /etc/createusers.conf
chmod 700 /etc/createusers.conf

# Copy the Welcome file unless the destination is newer
echo "Copie du message de bienvenue /etc/bienvenue.txt meme si nouveau"
cp -u bienvenue.txt /etc/bienvenue.txt 
chown root.root /etc/bienvenue.txt
chmod 777 /etc/bienvenue.txt 

# Copy checks to /usr/local/lib/createusers
echo "Copying checks to /usr/local/lib/createusers"
mkdir -p /usr/local/lib/createusers
chmod +x lib/*
chown root.root lib/*
cp -fp lib/* /usr/local/lib/createusers

# Copy scripts to /usr/sbin
echo "Scripts copies vers /usr/sbin"
chmod +x scripts/*
chown root.root scripts/*
cp -fp scripts/* /usr/sbin

# Set up ~/.my.cnf which stores MySQL password for use by MySQL client
echo "Creating ~/.my.cnf unless it already exists"
if ! test -e ~/.my.cnf; then
   echo > ~/.my.cnf "[client]"
   echo >> ~/.my.cnf "#password="
   chmod 700 ~/.my.cnf
fi

# Set up ~/.pg.password which stores Postgres password for use by psql
echo "Creating ~/.pg.password unless it already exists"
touch ~/.pg.password

# Create users group directory
#echo "Creating home directory for 'users' group unless it already exists"
#test -e /home/users || mkdir /home/users

echo ""
echo "Installed createusers."
echo ""
echo "Now continue to follow the instructions in the INSTALL file" 
echo "to complete your installation of createusers."
echo "This is free software. You are welcome to redistribute it" 
echo "under certain conditions. See the COPYING file for details."
echo ""
echo "Please send feedback and bug reports to the Linux for Schools Project."
echo "Email: phil@lfsp.org."
echo ""
